@@ -132,6 +132,7 @@ class Group(ModelSQL, ModelView):
             default = {}
         else:
             default = default.copy()
+        default.setdefault('number', None)
         default.setdefault('payments', None)
         return super(Group, cls).copy(groups, default=default)
 
@@ -538,7 +539,11 @@ class ProcessPayment(Wizard):
     process = StateAction('account_payment.act_payment_group_form')
 
     def _group_payment_key(self, payment):
-        return (('journal', payment.journal.id), ('kind', payment.kind))
+        return (
+            ('company', payment.company.id),
+            ('journal', payment.journal.id),
+            ('kind', payment.kind),
+            )
 
     def _new_group(self, values):
         pool = Pool()
