@@ -1,6 +1,9 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 
-from .test_account_payment import suite
+try:
+    from trytond.modules.account_payment.tests.test_account_payment import suite  # noqa: E501
+except ImportError:
+    from .test_account_payment import suite
 
 __all__ = ['suite']
